Struct daemon_engine::server::Request[][src]

pub struct Request<REQ, RESP> { /* fields omitted */ }

Request is a request from a client This contains the Request data and is a Sink for Response data

Methods

impl<REQ, RESP> Request<REQ, RESP> where
    REQ: Clone
[src]

Allows requests to be cloned