Struct daemon_engine::server::Server[][src]

pub struct Server<REQ, RESP> { /* fields omitted */ }

Server implements a daemon server This creates an IPC socket and listens for messages from connected clients

Methods

impl<REQ, RESP> Server<REQ, RESP> where
    REQ: Serialize + Deserialize<'de> + Clone + Send + Debug + 'static,
    RESP: Serialize + Deserialize<'de> + Clone + Send + Debug + 'static, 
[src]

Create a new server with the defined Request and Response types This starts a new listening thread using the provided runtime handle and provides a Source of Requests from connected clients